@@ -219,27 +219,35 @@ Brain2 <- R6::R6Class(
       }
     },
 
-    add_atlas = function(atlas, color_format = c("RGBAFormat", "RedFormat")){
+    add_atlas = function(atlas, color_format = c("RGBAFormat", "RedFormat"),
+                         trans_space_from = c("model", "scannerRAS")){
 
       color_format <- match.arg(color_format)
+      trans_space_from <- match.arg(trans_space_from)
 
       if(!inherits(atlas, 'brain-atlas')) {
 
         stopifnot2(is.character(atlas), msg = 'atlas must be a brain-atlas object or valid atlas name from FreeSurfer folder')
         atlas <- gsub("_", "+", atlas)
-        path_atlases <- file.path( self$base_path, "mri", sprintf("%s.mgz", atlas) )
+        path_atlases <- file.path( self$base_path, "mri", as.vector(rbind(
+          sprintf("%s.mgz", atlas),
+          sprintf("%s.nii.gz", atlas),
+          sprintf("%s.nii", atlas)
+        )) )
         atlas_path <- path_atlases[file.exists(path_atlases)]
         if(!length(atlas_path)) { return() }
         atlas_path <- atlas_path[[ 1 ]]
 
+        atlas_geom <- VolumeGeom2$new(
+          name = sprintf("Atlas - %s (%s)", atlas, subject_code),
+          path = atlas_path, color_format = color_format, trans_mat = NULL
+        )
+        atlas_geom$trans_space_from <- trans_space_from
         atlas_instance <- BrainAtlas$new(
           subject_code = private$.subject_code,
           atlas_type = atlas,
           position = c(0, 0, 0),
-          atlas = VolumeGeom2$new(
-            name = sprintf("Atlas - %s (%s)", atlas, subject_code),
-            path = atlas_path, color_format = color_format, trans_mat = NULL
-          )
+          atlas = atlas_geom
         )
         atlas_instance$group$.cache_name <- sprintf("%s/mri", private$.subject_code)
         atlas <- atlas_instance
@@ -656,7 +664,8 @@ Brain2 <- R6::R6Class(
         # add_voxel_cube(self, "CT", ct$get_data(), size = ct_shape,
         #                trans_mat = trans_mat, color_format = "RedFormat")
         add_nifti(self, "CT", path = ct_path,
-                  color_format = "RedFormat", trans_mat = trans_mat)
+                  color_format = "RedFormat", trans_mat = trans_mat,
+                  trans_space_from = "scannerRAS")
       }
 
       key <- seq(0, 5000)
@@ -680,6 +689,13 @@ Brain2 <- R6::R6Class(
       controllers[["Voxel Min"]] <- 3000
       controllers[["Edit Mode"]] %?<-% "CT/volume"
 
+      # check if surface exists
+      if(!length(self$surfaces)) {
+        controllers[["Overlay Coronal"]] %?<-% TRUE
+        controllers[["Overlay Axial"]] %?<-% TRUE
+        controllers[["Overlay Sagittal"]] %?<-% TRUE
+      }
+
       # Also add other atlases
       self$add_atlas("aparc+aseg")
       self$add_atlas("aparc.DKTatlas+aseg")
@@ -740,8 +756,13 @@ Brain2 <- R6::R6Class(
         side_display <- FALSE
       }
 
-      # # check if curvature files exist
-      # global_files =
+      # check if surface exists
+      if(!length(self$surfaces)) {
+        controllers <- as.list(controllers)
+        controllers[["Overlay Coronal"]] %?<-% TRUE
+        controllers[["Overlay Axial"]] %?<-% TRUE
+        controllers[["Overlay Sagittal"]] %?<-% TRUE
+      }
 
       threejs_brain(
         .list = geoms,
